@@ -42,21 +42,22 @@ class StandingBookServices():
                 enroll_record_map[i["enroll"]].append(i["user_info"].get("full_name", "该用户不存在"))
             else:
                 enroll_record_map[i["enroll"]] = [i["user_info"].get("full_name", "该用户不存在")]
+
         current_index = (page - 1) * size
         # 获取发票相关的信息
         for item in enroll_list:
             # 添加
             group_names_str = ""
-            for i in group_names.get(item["user_id"], []):
+            for i in group_names.get(item.get("user_id", ""), []):
                 group_names_str = group_names_str + ("," if len(group_names_str) > 0 else "") + i["group_name"]
             item["group_name"] = "游客" if not group_names_str else group_names_str  # 分组字符串
 
             current_index += 1
             item["index"] = current_index  # 序号
-            item["beneficiary"] = beneficiary_user_map.get(item["user_id"], "非业务人员邀请用户")  # 邀请用户
-            item["total"] = item["count"] * item["price"]  # 小计
-            item["beneficiary_amount"] = float(item["amount"]) * 0.6  # 业务员提成
-            item["urge_free"] = 50 if isinstance(item["is_urgent"], str) and int(item["is_urgent"]) else 0  # 加急费用
+            item["beneficiary"] = beneficiary_user_map.get(item.get("user_id"), "非业务人员邀请用户")  # 邀请用户
+            item["total"] = item.get("count", 0) * item.get("price", 0)  # 小计
+            item["beneficiary_amount"] = float(item.get("amount", 0)) * 0.6  # 业务员提成
+            item["urge_free"] = 50 if isinstance(item.get("is_urgent", None), str) and int(item["is_urgent"]) else 0  # 加急费用
             item["other_money"] = '-'  # 其他款项
 
             enroll_user_name_str = ""
